@@ -95,7 +95,7 @@ void CanvasMode_Normal::drawControls(QPainter* p)
 	}
 	else
 	{
-		drawSelection(p);
+		drawSelection(p, true);
 	}
 }
 
@@ -137,7 +137,6 @@ void CanvasMode_Normal::activate(bool fromGesture)
 	setModeCursor();
 	if (fromGesture)
 	{
-		m_canvas->m_viewMode.operItemResizeInEditMode = false;
 		m_view->update();
 	}
 }
@@ -754,6 +753,7 @@ void CanvasMode_Normal::mouseReleaseEvent(QMouseEvent *m)
 	m_canvas->m_viewMode.m_MouseButtonPressed = false;
 	m_canvas->resetRenderMode();
 	m->accept();
+	m_view->redrawMarker->hide();
 //	m_view->stopDragTimer();
 	//m_canvas->update(); //ugly in a mouseReleaseEvent!!!!!!!
 	if ((!GetItem(&currItem)) && (m->button() == Qt::RightButton) && (!m_doc->DragP))
@@ -926,7 +926,7 @@ void CanvasMode_Normal::mouseReleaseEvent(QMouseEvent *m)
 				QMatrix p;
 				m_canvas->Transform(docItem, p);
 			//	QRegion apr = QRegion(docItem->Clip * p);
-				QRect apr2(docItem->getRedrawBounding(m_canvas->scale()));
+				QRect  apr2 = m_canvas->canvasToLocal( docItem->getCurrentBoundingRect(docItem->lineWidth()) );
 			//	if (((Sele.contains(apr.boundingRect())) || (Sele.contains(apr2))) && (docItem->LayerNr == m_doc->activeLayer()) && (!m_doc->layerLocked(docItem->LayerNr)))
 				if ((Sele.contains(apr2)) && (docItem->LayerNr == m_doc->activeLayer()) && (!m_doc->layerLocked(docItem->LayerNr)))
 				{
@@ -945,7 +945,7 @@ void CanvasMode_Normal::mouseReleaseEvent(QMouseEvent *m)
 		}
 		m_view->HaveSelRect = false;
 		shiftSelItems = false;
-		m_view->redrawMarker->hide();
+//		m_view->redrawMarker->hide();
 		m_view->updateContents();
 	}
 	if (m_doc->appMode != modeEdit)
@@ -1204,11 +1204,13 @@ bool CanvasMode_Normal::SeleItem(QMouseEvent *m)
 		m_doc->m_Selection->delaySignalsOff();
 		if (m_doc->m_Selection->count() > 1)
 		{
+			m_doc->beginUpdate();
 			for (int aa = 0; aa < m_doc->m_Selection->count(); ++aa)
 			{
 				PageItem *bb = m_doc->m_Selection->itemAt(aa);
 				bb->update();
 			}
+			m_doc->endUpdate();
 			m_doc->m_Selection->setGroupRect();
 			double x, y, w, h;
 			m_doc->m_Selection->getGroupRect(&x, &y, &w, &h);
