@@ -54,6 +54,20 @@ OutlineWidget::OutlineWidget(QWidget* parent) : QTreeWidget(parent)
 {
 }
 
+void OutlineWidget::selectItems(QList<QTreeWidgetItem*> items)
+{
+	QItemSelection itemSelection;
+	for (int i = 0; i < items.count(); ++i)
+	{
+		QModelIndex index = this->indexFromItem(items.at(i));
+		if (index.isValid())
+		{
+			itemSelection.select(index, index);
+		}
+	}
+	selectionModel()->select(itemSelection, QItemSelectionModel::Select);
+}
+
 bool OutlineWidget::viewportEvent(QEvent *event)
 {
 	if (event->type() == QEvent::ToolTip)
@@ -223,7 +237,7 @@ void OutlinePalette::setPaletteShown(bool visible)
 
 void OutlinePalette::slotRightClick(QPoint point)
 {
-	if (!m_MainWindow || m_MainWindow->ScriptRunning)
+	if (!m_MainWindow || m_MainWindow->scriptIsRunning())
 		return;
 	QTreeWidgetItem *ite = reportDisplay->itemAt(point);
 	if (ite == NULL)
@@ -257,7 +271,7 @@ void OutlinePalette::slotRenameItem()
 
 void OutlinePalette::slotDoRename(QTreeWidgetItem *ite , int col)
 {
-	if (!m_MainWindow || m_MainWindow->ScriptRunning)
+	if (!m_MainWindow || m_MainWindow->scriptIsRunning())
 		return;
 	disconnect(reportDisplay, SIGNAL(itemChanged(QTreeWidgetItem*, int)), this, SLOT(slotDoRename(QTreeWidgetItem*, int)));
 	OutlineTreeItem *item = (OutlineTreeItem*)ite;
@@ -373,7 +387,7 @@ QTreeWidgetItem* OutlinePalette::getListItem(int SNr, int Nr)
 
 void OutlinePalette::slotShowSelect(uint SNr, int Nr)
 {
-	if (!m_MainWindow || m_MainWindow->ScriptRunning)
+	if (!m_MainWindow || m_MainWindow->scriptIsRunning())
 		return;
 	if (currDoc==NULL)
 		return;
@@ -385,14 +399,16 @@ void OutlinePalette::slotShowSelect(uint SNr, int Nr)
 	reportDisplay->clearSelection();
 	if (currDoc->m_Selection->count() > 0)
 	{
+		QList<QTreeWidgetItem*> itemSelection;
 		uint docSelectionCount = currDoc->m_Selection->count();
 		for (uint a = 0; a < docSelectionCount; a++)
 		{
 			PageItem *item = currDoc->m_Selection->itemAt(a);
 			QTreeWidgetItem *retVal = getListItem(item->OwnPage, item->ItemNr);
 			if (retVal != 0)
-				retVal->setSelected(true);
+				itemSelection.append(retVal);
 		}
+		reportDisplay->selectItems(itemSelection);
 	}
 	else
 	{
@@ -464,7 +480,7 @@ void OutlinePalette::setItemIcon(QTreeWidgetItem *item, PageItem *pgItem)
 
 void OutlinePalette::reopenTree()
 {
-	if (!m_MainWindow || m_MainWindow->ScriptRunning)
+	if (!m_MainWindow || m_MainWindow->scriptIsRunning())
 		return;
 	if (currDoc->OpenNodes.count() == 0)
 		return;
@@ -519,7 +535,7 @@ void OutlinePalette::buildReopenVals()
 
 void OutlinePalette::slotMultiSelect()
 {
-	if (!m_MainWindow || m_MainWindow->ScriptRunning)
+	if (!m_MainWindow || m_MainWindow->scriptIsRunning())
 		return;
 	if (currDoc==NULL)
 		return;
@@ -572,7 +588,7 @@ void OutlinePalette::slotMultiSelect()
 
 void OutlinePalette::slotSelect(QTreeWidgetItem* ite, int col)
 {
-	if (!m_MainWindow || m_MainWindow->ScriptRunning)
+	if (!m_MainWindow || m_MainWindow->scriptIsRunning())
 		return;
 	selectionTriggered = true;
 	OutlineTreeItem *item = (OutlineTreeItem*)ite;
@@ -628,7 +644,7 @@ void OutlinePalette::resizeEvent(QResizeEvent *r)
 */
 void OutlinePalette::BuildTree(bool storeVals)
 {
-	if (!m_MainWindow || m_MainWindow->ScriptRunning)
+	if (!m_MainWindow || m_MainWindow->scriptIsRunning())
 		return;
 	if (currDoc==NULL)
 		return;
