@@ -299,6 +299,7 @@ void Scribus134Format::writeCheckerProfiles(ScXmlStreamWriter & docu)
 		docu.writeAttribute("checkRasterPDF", static_cast<int>(itcp.value().checkRasterPDF));
 		docu.writeAttribute("checkForGIF", static_cast<int>(itcp.value().checkForGIF));
 		docu.writeAttribute("ignoreOffLayers", static_cast<int>(itcp.value().ignoreOffLayers));
+		docu.writeAttribute("checkOffConflictLayers", static_cast<int>(itcp.value().checkOffConflictLayers));
 		//docu.writeEndElement();
 	}
 }
@@ -1009,13 +1010,17 @@ void Scribus134Format::writeITEXTs(ScribusDoc *doc, ScXmlStreamWriter &docu, Pag
 				putCStylePT(docu, lastStyle);
 			else*/
 				putCStyle(docu, lastStyle);
-			docu.writeAttribute("CH", QString(ch));
+			tmpnum.setNum(ch.unicode());
+			docu.writeAttribute("Unicode", tmpnum);
 			docu.writeAttribute("COBJ", item->itemText.object(k)->ItemNr);		
 		}
 		else if (ch == SpecialChars::PARSEP)	// stores also the paragraphstyle for preceding chars
 			putPStyle(docu, item->itemText.paragraphStyle(k), "para");
 		else if (ch == SpecialChars::TAB)
+		{
 			docu.writeEmptyElement("tab");
+			putCStyle(docu, lastStyle);
+		}
 		else if (ch == SpecialChars::LINEBREAK)
 			docu.writeEmptyElement("breakline");
 		else if (ch == SpecialChars::COLBREAK)
@@ -1071,7 +1076,7 @@ void Scribus134Format::writeITEXTs(ScribusDoc *doc, ScXmlStreamWriter &docu, Pag
 	// paragraphstyle for trailing chars
 	if (item->itemText.length() == 0 || item->itemText.text(item->itemText.length()-1) != SpecialChars::PARSEP)
 	{
-		putPStyle(docu, item->itemText.paragraphStyle(item->itemText.length()), "para");
+		putPStyle(docu, item->itemText.paragraphStyle(item->itemText.length()), "trail");
 	}
 }
 
