@@ -672,6 +672,14 @@ public:
 	   @param dia optional progress widget
 	 */
 	void RecalcPictures(ProfilesL *Pr, ProfilesL *PrCMYK, QProgressBar *dia = 0);
+	/**
+	 * \brief Handle image with color profiles
+	 * @param items list of page items to update
+	 * @param Pr profile
+	 * @param PrCMYK cmyk profile
+	 * @param dia optional progress widget
+	 */
+	void RecalcPictures(QList<PageItem*>* items, ProfilesL *Pr, ProfilesL *PrCMYK, QProgressBar *dia = 0);
 	/**
 	 * @brief Find the minX,MinY and maxX,maxY for the canvas required for the doc
 	 */
@@ -691,7 +699,8 @@ public:
 	double getXOffsetForPage(const int);
 	double getYOffsetForPage(const int);
 	void getBleeds(int pageNumber, MarginStruct& bleedData);
-	void getBleeds(Page* page, MarginStruct& bleedData);
+	void getBleeds(const Page* page, MarginStruct& bleedData);
+	void getBleeds(const Page* page, const MarginStruct& baseValues, MarginStruct& bleedData);
 	
 	/**
 	 * @brief Item type conversion functions
@@ -889,6 +898,11 @@ public:
 	void scaleGroup(double scx, double scy, bool scaleText=true, Selection* customSelection = 0);
 	//! \brief Get a list of frames of certain type
 	QMap<PageItem*, QString> getDocItemNames(PageItem::ItemType itemType);
+
+	//! \brief Fonctions which avoid doc updater and update manager to send too much
+	// unncessary signals when doing updates on multiple items
+	void beginUpdate();
+	void endUpdate();
 	
 protected:
 	void addSymbols();
